@@ -200,12 +200,7 @@ class MongoDBStorage(Storage, MovingWindowSupport):
                             "$filter": {
                                 "input": "$entries",
                                 "as": "entry",
-                                "cond": {
-                                    "$gte": [
-                                        "$$entry",
-                                        timestamp - expiry,
-                                    ]
-                                },
+                                "cond": {"$gte": ["$$entry", timestamp - expiry,]},
                             }
                         }
                     }
